const express = require('express')
const http = require('http')
const bodyParser = require('body-parser')
const app = express()
const port = process.env.port || 3999

const env = ['development', 'test', 'production', 'unittest']

if (!~env.indexOf(process.env.NODE_ENV)) {
  console.log('environmental variable required, must be of development、test、production or unittest. eg: NODE_ENV=development node xxx.js')
  process.exit(1)
}

/**
 * Log is a property of the global object,
 * so the dependency on Log should be in front of other dependencies
 */
require('./lib/log.js')

const router = require('./routers')

app.use(bodyParser.json())
app.use(bodyParser.urlencoded({ extended: false }))

app.use((req, res, next) => {
  res.header('Access-Control-Allow-Origin', '*')
  res.header('Access-Control-Allow-Headers', 'Content-Type')
  res.header('Access-Control-Allow-Credentials', true)
  req.header('Access-Control-Max-Age', 600)
  if (req.method === 'OPTIONS') return res.end()
  return next()
})

app.use((req, res, next) => {
  Log.data('request enter', {'http-method': req.method, 'uri': req.originalUrl, 'query': req.query, 'body': req.body})
  return next()
})

app.use(router)

app.set('etag', false)

http.createServer(app).listen(port, function () {
  Log.data('jj-proxy server start', {port: port})
})
