const winston = require('winston')
require('winston-mongodb')

const logConfig = {
  levels: {
    fatal: 0,
    error: 1,
    warn: 2,
    data: 3,
    debug: 4
  },
  colors: {
    fatal: 'bold red whiteBG',
    error: 'red',
    warn: 'yellow',
    data: 'green',
    debug: 'blue'
  }
}

const logger = winston.createLogger({
  levels: logConfig.levels,
  level: 'data',
  format: winston.format.combine(
    winston.format.timestamp({format: 'YYYY-MM-DD HH:mm:ss:SSS'}),
    winston.format.json()
  ),
  transports: [
    new winston.transports.File({ filename: 'error.log', level: 'error' }),
    new winston.transports.File({ filename: 'combined.log' })
  ]
})

if (process.env.NODE_ENV !== 'production') {
  winston.addColors(logConfig.colors)

  logger.add(new winston.transports.Console({
    level: 'debug',
    format: winston.format.combine(
      winston.format.colorize(),
      winston.format.simple()
    )
  }))

  logger.add(new winston.transports.MongoDB({
    level: 'data',
    db: 'mongodb://127.0.0.1:30000/jj-proxy-logs',
    options: {poolSize: 2, autoReconnect: true},
    collection: 'logs',
    capped: true,
    cappedMax: 1000000
  }))
}

global.Log = logger
